#[repr(u8)]pub enum RealmType {
Door = 0,
Drink = 1,
MemberProjects = 2,
}Expand description
Selects a known realm.
Variants
Door = 0
The Door (slot 0) realm is used by door locks to gate access to common rooms.
Drink = 1
The Drink (slot 1) realm is used to authorize drink credit purchases.
MemberProjects = 2
The MemberProjects (slot 2) realm is used by anything lower-security
that doesn’t fall into any of those categories (e.g. harold-nfc).
If you’re looking to make a new project, this is probably the realm you
should use!